@@ -38,17 +38,22 @@ class KCheckGmailTray : public KSystemTray, virtual public KCheckGmailIface
 	Q_OBJECT
 public:
 	KCheckGmailTray(QWidget *parent = 0, const char *name = 0);
+	void start();
 
 protected:
 	void mousePressEvent(QMouseEvent*);
 
 	void setPixmapAuth();
+	void setPixmapSnooze();
 	void setPixmapEmpty();
+	
+	void toggleAnim(bool restoreToState);
 
 protected slots:
 	// KPopupMenu
 	void slotContextMenuActivated(int);
 	void slotThreadsMenuActivated(int);
+	void slotThreadsItemHighlighted(int);
 
 	// KConfigDialog
 	void slotSettingsChanged();
@@ -58,12 +63,14 @@ protected slots:
 	void slotLoginDone(bool success, bool spawnedFromTimer, const QString &errmsg);
 	void slotLoginStart();
 	void slotCheckStart();
+	void slotSessionChanged();
 	void slotCheckDone(const QString &data);
 
 	// GMailParser
 	void slotMailArrived(unsigned int n);
 	void slotMailCountChanged();
 	void slotVersionMismatch();
+	void slotgNameChanged(QString name);
 
 	// login "animation"
 	void slotToggleLoginAnim();
@@ -73,11 +80,17 @@ private:
 	void showKNotifyDialog();
 	void updateCountImage();
 	void updateThreadMenu();
+	void composeMail();
+	void snooze();
 	void initConfigDialog();
+	QString getUrlBase();
 
 	// dcop call implementations
 	int mailCount() const { return mMailCount; };
 	void checkMailNow();
+	void whereAmI();
+	
+	void takeScreenshotOfTrayIcon();
 
 	QPixmap		mPixGmail,
 			mPixCount;
@@ -90,11 +103,12 @@ private:
 	KIconEffect mIconEffect;
 	QTimer *mLoginAnim;
 
-	// menu id for the check now button
-	int 		mCheckNowId;
-
-	int 		mThreadsMenuId;
+	// menu ids
+	int	mCheckNowId;
+	int	mThreadsMenuId;
 
 	// mail count for dcop interface
-	int		mMailCount;
+	int	mMailCount;
+	
+	bool isSnoozing;
 };
